@@ -39,7 +39,7 @@ if __name__ == '__main__':
     from cashbox.app import App, MinWindow
 
 try:
-    from cashbox.utils import eprint, create_action
+    from cashbox.utils import create_action
     from cashbox.read_appargs import appargs
     from cashbox.article import Article, Sale, cent2str, str2cent
     from cashbox.cshbx import Cshbx
@@ -142,17 +142,20 @@ In the {d.R} window the {d.p} to pay is shown. The paid amount can be entered \
 and the return will be shown. With 'Ok' the sale will be saved and the \
 selected {d.a} {d.cs} will be resetted for the next customer.""")))
 
-    def on_money_in(self, _a, _b):
-        """ x """
+    def set_money_out(self):
+        """ set money_out depending on money_sum and money_in """
         money_sum = str2cent(self.money_sum_buffer.get_text())
-        money_in_text = self.money_in_buffer.get_text()
+        money_in = str2cent(self.money_in_buffer.get_text(), True)
         money_out_text = ""
-        money_in = str2cent(money_in_text, True)
         if money_in and money_sum:
             if money_in > money_sum:
                 money_out_text = cent2str(money_in - money_sum)
         self.money_out_buffer.set_text(money_out_text, len(money_out_text))
 
+    def on_money_in(self, _a, _b):
+        """ recalc money_out depending on money_in """
+        self.set_money_out()
+
     @Gtk.Template.Callback()
     def on_map_sum(self, _widget):
         """ x """
@@ -167,9 +170,10 @@ selected {d.a} {d.cs} will be resetted for the next customer.""")))
         s = cent2str(paysum)
         # print(f"on_map_sum will set <{s}>")
         self.money_sum_buffer.set_text(s, len(s))
+        self.set_money_out()
 
     @Gtk.Template.Callback()
-    def on_save_receipt(self, button):
+    def on_save_receipt(self, _button):
         """ x """
         # eprint(f"on_savereceipt: button=<{button}>")
         session_dir = os.path.join(appargs.user_app_dir, appargs.session)
@@ -282,7 +286,6 @@ if __name__ == '__main__':
         def list_sale_clicked(self, _list_button):
             """ x """
             # print(f"list_sale_clicked: sale=<{self.sale}>")
-            pass
 
         def quit_clicked(self, _list_button):
             """ x """
